netapp_ontap.models.chassis_node API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.chassis_node`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ChassisNodeSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ChassisNode object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `links: SelfLink GET`

    The links field of the chassis_node.

  `name: str GET POST PATCH`

    The name field of the chassis_node.

    Example: node1

  `pcis: ChassisNodesPcis GET POST PATCH`

    The pcis field of the chassis_node.

  `position: str GET POST PATCH`

    The position of the node in the chassis, when viewed from the rear of the system.

    Valid choices:

    - top
    - bottom
    - left
    - right
    - centre
    - unknown
  `usbs: ChassisNodesUsbs GET POST PATCH`

    The status of the USB ports on the controller.

  `uuid: str GET POST PATCH`

    The uuid field of the chassis_node.

    Example: 1cd8a442-86d1-11e0-ae1c-123478563412